@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Appier Framework
-# Copyright (c) 2008-2019 Hive Solutions Lda.
+# Copyright (c) 2008-2020 Hive Solutions Lda.
 #
 # This file is part of Hive Appier Framework.
 #
@@ -28,7 +28,7 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2019 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2020 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -86,7 +86,7 @@ from .asynchronous import ASYNC_HEADER, AsyncManager, SimpleManager, QueueManage
 from .base import APP, LEVEL, NAME, VERSION, PLATFORM, IDENTIFIER_SHORT, IDENTIFIER_LONG, IDENTIFIER,\
     API_VERSION, BUFFER_SIZE, MAX_LOG_SIZE, MAX_LOG_COUNT, App, APIApp, WebApp, Template, get_app, get_name,\
     get_base_path, get_cache, get_preferences, get_bus, get_request, get_session, get_model, get_controller, get_part,\
-    get_adapter, get_manager, get_logger, get_level, is_loaded, is_devel, is_safe, to_locale, on_exit
+    get_adapter, get_manager, get_logger, get_level, is_loaded, is_devel, is_safe, to_locale, on_exit, build_asgi, build_asgi_i
 from .bus import Bus, MemoryBus, RedisBus
 from .cache import Cache, MemoryCache, FileCache, RedisCache, SerializedCache
 from .component import Component
@@ -113,7 +113,8 @@ from .log import MemoryHandler, BaseFormatter, ThreadFormatter, DummyLogger, rel
 from .meta import Ordered, Indexed
 from .mock import MockObject, MockResponse, MockApp
 from .model import Model, LocalModel, Field, link, operation, view, field, type_d, is_unset
-from .mongo import Mongo, MongoEncoder, get_connection, reset_connection, get_db, drop_db, object_id, dumps
+from .mongo import Mongo, MongoAsync, MongoEncoder, get_connection, get_connection_a, reset_connection, reset_connection_a,\
+    get_db, get_db_a, drop_db, drop_db_a, object_id, dumps
 from .observer import Observable
 from .part import Part
 from .preferences import Preferences, MemoryPreferences, FilePreferences, RedisPreferences
@@ -133,8 +134,8 @@ from .typesf import AbstractType, Type, File, Files, ImageFile, ImageFiles, imag
 from .util import is_iterable, is_mobile, is_tablet, is_browser, is_bot, browser_info, email_parts, email_mime,\
     email_name, email_base, date_to_timestamp, obfuscate, import_pip, ensure_pip, install_pip, install_pip_s,\
     request_json, get_context, get_object, resolve_alias, page_types, find_types, norm_object, set_object, leafs,\
-    gather_errors, gen_token, html_to_text, camel_to_underscore, camel_to_readable, underscore_to_readable, quote,\
-    unquote, escape, unescape, split_unescape, call_safe, base_name, base_name_m, is_content_type, parse_content_type,\
+    gather_errors, gen_token, html_to_text, camel_to_underscore, camel_to_readable, underscore_to_camel, underscore_to_readable, quote,\
+    unquote, escape, unescape, count_unescape, split_unescape, call_safe, base_name, base_name_m, is_content_type, parse_content_type,\
     parse_cookie, parse_multipart, decode_params, load_form, check_login, check_user, check_token, check_tokens,\
     ensure_login, get_tokens_m, to_tokens_m, dict_merge, deprecated, cached, private, ensure, delayed, route, error_handler,\
     exception_handler, before_request, after_request, is_detached, sanitize, verify, verify_equal, verify_not_equal,\
