@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Appier Framework
-# Copyright (c) 2008-2019 Hive Solutions Lda.
+# Copyright (c) 2008-2020 Hive Solutions Lda.
 #
 # This file is part of Hive Appier Framework.
 #
@@ -31,7 +31,7 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2019 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2020 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -108,8 +108,10 @@ class AyncgenWrapper(object):
     def __next__(self):
         if self._buffer: return self._buffer.pop(0)
         try:
-            if self.current == None: self.current = self.async_iter.asend(None)
-            try: return next(self.current)
+            if self.current == None:
+                self.current = self.async_iter.asend(None)
+            try:
+                return next(self.current)
             except StopIteration as exception:
                 self.current = None
                 if not exception.args: return None
