@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Appier Framework
-# Copyright (c) 2008-2019 Hive Solutions Lda.
+# Copyright (c) 2008-2020 Hive Solutions Lda.
 #
 # This file is part of Hive Appier Framework.
 #
@@ -31,7 +31,7 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2019 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2020 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -146,8 +146,10 @@ class LegacyTest(unittest.TestCase):
             appier.legacy.bytes("%E4%BD%A0%E5%A5%BD%E4%B8%96%E7%95%8C"),
             encoding = "utf-8"
         )
-        if appier.legacy.PYTHON_3: self.assertRaises(TypeError, method)
-        else: self.assertEqual(value, "你好世界")
+        if not appier.legacy.PYTHON_3 or not appier.legacy.PYTHON_39:
+            self.assertRaises(TypeError, method)
+        elif appier.legacy.PYTHON_3:
+            self.assertEqual(method(), "你好世界")
 
     def test_tobytes(self):
         value = array.array("B")
