@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Appier Framework
-# Copyright (c) 2008-2019 Hive Solutions Lda.
+# Copyright (c) 2008-2020 Hive Solutions Lda.
 #
 # This file is part of Hive Appier Framework.
 #
@@ -31,7 +31,7 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2019 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2020 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -491,6 +491,13 @@ class UtilTest(unittest.TestCase):
         self.assertEqual(errors, dict())
 
     def test_camel_to_underscore(self):
+        result = appier.camel_to_underscore(None)
+        self.assertEqual(result, None)
+
+        result = appier.camel_to_underscore("")
+        self.assertEqual(type(result), str)
+        self.assertEqual(result, "")
+
         result = appier.camel_to_underscore("HelloWorld")
         self.assertEqual(type(result), str)
         self.assertEqual(result, "hello_world")
@@ -504,6 +511,13 @@ class UtilTest(unittest.TestCase):
         self.assertEqual(result, "hello_world_hello_world")
 
     def test_camel_to_readable(self):
+        result = appier.camel_to_readable(None)
+        self.assertEqual(result, None)
+
+        result = appier.camel_to_readable("")
+        self.assertEqual(type(result), str)
+        self.assertEqual(result, "")
+
         result = appier.camel_to_readable("HelloWorld")
         self.assertEqual(type(result), str)
         self.assertEqual(result, "Hello World")
@@ -551,7 +565,78 @@ class UtilTest(unittest.TestCase):
         self.assertEqual(type(result), str)
         self.assertEqual(result, "Hello World Hello World")
 
+    def test_underscore_to_camel(self):
+        result = appier.underscore_to_camel(None)
+        self.assertEqual(result, None)
+
+        result = appier.underscore_to_camel("")
+        self.assertEqual(type(result), str)
+        self.assertEqual(result, "")
+
+        result = appier.underscore_to_camel("hello_world")
+        self.assertEqual(type(result), str)
+        self.assertEqual(result, "HelloWorld")
+
+        result = appier.underscore_to_camel("hello_world", lower = True)
+        self.assertEqual(type(result), str)
+        self.assertEqual(result, "helloWorld")
+
+        result = appier.underscore_to_camel("hello_world_hello_world")
+        self.assertEqual(type(result), str)
+        self.assertEqual(result, "HelloWorldHelloWorld")
+
+        result = appier.underscore_to_camel("hello_world_hello_world", lower = True)
+        self.assertEqual(type(result), str)
+        self.assertEqual(result, "helloWorldHelloWorld")
+
+        result = appier.underscore_to_camel("hello_world_")
+        self.assertEqual(type(result), str)
+        self.assertEqual(result, "HelloWorld")
+
+        result = appier.underscore_to_camel("hello_world_", lower = True)
+        self.assertEqual(type(result), str)
+        self.assertEqual(result, "helloWorld")
+
+        result = appier.underscore_to_camel("__hello_world__")
+        self.assertEqual(type(result), str)
+        self.assertEqual(result, "HelloWorld")
+
+        result = appier.underscore_to_camel("__hello_world__", lower = True)
+        self.assertEqual(type(result), str)
+        self.assertEqual(result, "helloWorld")
+
+        result = appier.underscore_to_camel("__hello___world__")
+        self.assertEqual(type(result), str)
+        self.assertEqual(result, "HelloWorld")
+
+        result = appier.underscore_to_camel("__hello___world__", lower = True)
+        self.assertEqual(type(result), str)
+        self.assertEqual(result, "helloWorld")
+
+        result = appier.underscore_to_camel("__hello___WORLD__")
+        self.assertEqual(type(result), str)
+        self.assertEqual(result, "HelloWORLD")
+
+        result = appier.underscore_to_camel("__hello___WORLD__", lower = True)
+        self.assertEqual(type(result), str)
+        self.assertEqual(result, "helloWORLD")
+
+        result = appier.underscore_to_camel("HelloWorld")
+        self.assertEqual(type(result), str)
+        self.assertEqual(result, "HelloWorld")
+
+        result = appier.underscore_to_camel("HelloWorld", lower = True)
+        self.assertEqual(type(result), str)
+        self.assertEqual(result, "helloWorld")
+
     def test_underscore_to_readable(self):
+        result = appier.underscore_to_readable(None)
+        self.assertEqual(result, None)
+
+        result = appier.underscore_to_readable("")
+        self.assertEqual(type(result), str)
+        self.assertEqual(result, "")
+
         result = appier.underscore_to_readable("hello_world")
         self.assertEqual(type(result), str)
         self.assertEqual(result, "Hello world")
@@ -592,6 +677,10 @@ class UtilTest(unittest.TestCase):
         self.assertEqual(type(result), str)
         self.assertEqual(result, "Hello World")
 
+        result = appier.underscore_to_readable("__hello___world__", capitalize = True, separator = "-")
+        self.assertEqual(type(result), str)
+        self.assertEqual(result, "Hello-World")
+
     def test_escape(self):
         result = appier.escape("foo,bar", ",", escape = "$")
         self.assertEqual(result, "foo$,bar")
@@ -609,6 +698,28 @@ class UtilTest(unittest.TestCase):
         result = appier.unescape("$$foo$,bar$$$$", escape = "$")
         self.assertEqual(result, "$foo,bar$$")
 
+    def test_count_unescape(self):
+        result = appier.count_unescape("foo:bar", ":")
+        self.assertEqual(result, 1)
+
+        result = appier.count_unescape("foo:bar:hello:world", ":")
+        self.assertEqual(result, 3)
+
+        result = appier.count_unescape("foo,bar,hello,world", ":")
+        self.assertEqual(result, 0)
+
+        result = appier.count_unescape("foo:bar\\:hello:world", ":")
+        self.assertEqual(result, 2)
+
+        result = appier.count_unescape("foo:bar\\:hello\\:world", ":")
+        self.assertEqual(result, 1)
+
+        result = appier.count_unescape("foo:bar\\:hello\\\\:world", ":")
+        self.assertEqual(result, 2)
+
+        result = appier.count_unescape("foo\\:bar\\:hello\\:world", ":")
+        self.assertEqual(result, 0)
+
     def test_split_unescape(self):
         result = appier.split_unescape("foo bar")
         self.assertEqual(result, ["foo", "bar"])
